pub enum AccessDecisionVerdict {
Deny,
Approve,
__Unknown(i64),
}Expand description
AccessDecisionVerdict : An approver’s verdict on a pending access request, as it appears on the
wire: 0 = deny, 1 = approve. An approver’s verdict on a pending access request, as it
appears on the wire: 0 = deny, 1 = approve.
Variants
Deny
Approve
__Unknown(i64)
Unknown value returned from the server. This is used to handle forward compatibility.
Implementations